@@ -204,7 +204,7 @@ class RouterboardResource(object):
         for key, value in dictionary.iteritems():
             if key in ['=.id', '=.proplist']:
                 key = key[1:]
-            elements.append((key[1:], value))
+            elements.append((key, value))
         return dict(elements)
 
     def get(self, **kwargs):
@@ -230,7 +230,10 @@ class RouterboardAPI(object):
     def __init__(self, host, username='api', password=''):
         sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         sock.settimeout(30.0)
-        sock.connect((host, self.port))
+        try:
+            sock.connect((host, self.port))
+        except socket.error as e:
+            raise RosAPIFatalError(str(e))
         socket_utils.set_keepalive(sock, after_idle_sec=10)
 
         self.api_client = RosAPI(sock)
